Crate lex_sleuther_multiplexer

Crate lex_sleuther_multiplexer 

Structs

LexerResult

Enums

BatchTokenKind
HtmlTokenKind
JsTokenKind
PowerShellTokenKind
PythonTokenKind
Vb6TokenKind

Functions

lexer_results_from_bytes
Given a vector of bytes that is already in memory, compute the feature vector derived from our hoard of lexers.
lexer_results_from_file
Given a file path, scan over the file and count tokens and errors from our hoard of lexers.
lexer_results_from_scanner
Given an Iterator over Unicode char’s, computes the feature vector derived from our hoard of lexers. This is the meat and potatoes of this library.

Type Aliases

BatchLexer
HtmlLexer
JsLexer
PowerShellLexer
PythonLexer
Vb6Lexer