Structs
Enums
Functions
- lexer_
results_ from_ bytes - Given a vector of bytes that is already in memory, compute the feature vector derived from our hoard of lexers.
- lexer_
results_ from_ file - Given a file path, scan over the file and count tokens and errors from our hoard of lexers.
- lexer_
results_ from_ scanner - Given an Iterator over Unicode
char’s, computes the feature vector derived from our hoard of lexers. This is the meat and potatoes of this library.